package NetHack::Item::Meta::Trait::IncorporatesUndef;
{
  $NetHack::Item::Meta::Trait::IncorporatesUndef::VERSION = '0.20';
}
use Moose::Role;
Moose::Util::meta_attribute_alias 'IncorporatesUndef';

1;

